@@ -1,5 +1,6 @@
 """All GQL endpoint extractor functions."""
 
+from typing import List, Optional, Set
 from urllib.parse import urljoin
 
 import aiohttp
@@ -14,7 +15,7 @@ from graphinder.utils.finders import find_script_fetch_graphql, find_script_full
 def extract_scripts_from_html(
     url: str,
     html: str,
-) -> list[str]:
+) -> List[str]:
     """Get any scripts files from html page."""
 
     soup = bs4(html, 'html.parser')
@@ -22,7 +23,7 @@ def extract_scripts_from_html(
     scripts_files = []
     for script in soup.find_all('script'):
 
-        src: str | None = script.attrs.get('src')
+        src: Optional[str] = script.attrs.get('src')
 
         if src:
             script_url = urljoin(url, script.attrs.get('src'))
@@ -34,10 +35,10 @@ def extract_scripts_from_html(
 async def extract_script_urls_from_page(
     session: aiohttp.ClientSession,
     url: str,
-) -> set[Url]:
+) -> Set[Url]:
     """This extractor will check all scripts on the page for GQL endpoints."""
 
-    urls: set[Url] = set()
+    urls: Set[Url] = set()
 
     try:
         async with session.get(url, timeout=10) as page:
@@ -59,10 +60,10 @@ async def extract_script_urls_from_page(
 def extract_scripts_from_raw_js(
     url: str,
     script_file: str,
-) -> set[str]:
+) -> Set[str]:
     """Extract all urls from a script file by using combination of regex."""
 
-    urls: list[str] = find_script_full_urls(script_file) + find_script_window_base_urls(url, script_file) + find_script_fetch_graphql(url, script_file)
+    urls: List[str] = find_script_full_urls(script_file) + find_script_window_base_urls(url, script_file) + find_script_fetch_graphql(url, script_file)
 
     return filter_common(set(urls))
 
@@ -70,10 +71,10 @@ def extract_scripts_from_raw_js(
 async def extract_urls_from_script(
     session: aiohttp.ClientSession,
     url: str,
-) -> set[Url]:
+) -> Set[Url]:
     """Extract urls from scripts."""
 
-    potentials_gqls: set[Url] = set()
+    potentials_gqls: Set[Url] = set()
     if not url.endswith('.js'):
         return set()
 
@@ -82,7 +83,7 @@ async def extract_urls_from_script(
         async with session.get(url, timeout=10) as script:
             _content: str = await script.text()
 
-            _urls: set[str] = extract_scripts_from_raw_js(domain_url, _content)
+            _urls: Set[str] = extract_scripts_from_raw_js(domain_url, _content)
 
             for potential in _urls:
                 if not potential.endswith('/graphql') or not domain_url in potential:
